import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FunctionAppHybridConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the Function App for this Hybrid Connection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#function_app_id FunctionAppHybridConnection#function_app_id}
    */
    readonly functionAppId: string;
    /**
    * The hostname of the endpoint.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#hostname FunctionAppHybridConnection#hostname}
    */
    readonly hostname: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#id FunctionAppHybridConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The port to use for the endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#port FunctionAppHybridConnection#port}
    */
    readonly port: number;
    /**
    * The ID of the Relay Hybrid Connection to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#relay_id FunctionAppHybridConnection#relay_id}
    */
    readonly relayId: string;
    /**
    * The name of the Relay key with `Send` permission to use. Defaults to `RootManageSharedAccessKey`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#send_key_name FunctionAppHybridConnection#send_key_name}
    */
    readonly sendKeyName?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#timeouts FunctionAppHybridConnection#timeouts}
    */
    readonly timeouts?: FunctionAppHybridConnectionTimeouts;
}
export interface FunctionAppHybridConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#create FunctionAppHybridConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#delete FunctionAppHybridConnection#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#read FunctionAppHybridConnection#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection#update FunctionAppHybridConnection#update}
    */
    readonly update?: string;
}
export declare function functionAppHybridConnectionTimeoutsToTerraform(struct?: FunctionAppHybridConnectionTimeouts | cdktf.IResolvable): any;
export declare class FunctionAppHybridConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FunctionAppHybridConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: FunctionAppHybridConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection azurerm_function_app_hybrid_connection}
*/
export declare class FunctionAppHybridConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_function_app_hybrid_connection";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.54.0/docs/resources/function_app_hybrid_connection azurerm_function_app_hybrid_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FunctionAppHybridConnectionConfig
    */
    constructor(scope: Construct, id: string, config: FunctionAppHybridConnectionConfig);
    private _functionAppId?;
    get functionAppId(): string;
    set functionAppId(value: string);
    get functionAppIdInput(): string | undefined;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    get hostnameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get namespaceName(): string;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _relayId?;
    get relayId(): string;
    set relayId(value: string);
    get relayIdInput(): string | undefined;
    get relayName(): string;
    private _sendKeyName?;
    get sendKeyName(): string;
    set sendKeyName(value: string);
    resetSendKeyName(): void;
    get sendKeyNameInput(): string | undefined;
    get sendKeyValue(): string;
    get serviceBusNamespace(): string;
    get serviceBusSuffix(): string;
    private _timeouts;
    get timeouts(): FunctionAppHybridConnectionTimeoutsOutputReference;
    putTimeouts(value: FunctionAppHybridConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | FunctionAppHybridConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
